﻿using eTraining.Commands;
using eTraining.Models;
using Kometa.Helpers;
using Kometa.Models;
using Kometa.Views;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace Kometa.ViewModels
{
    class MainWindowViewModel :ViewModelBase
    {
        private Uzivatel _prihlasenyUz;
        private KompetencniMatice.Models.KontaktniOsoba _kontakt;
        private Usek _aktivniUsek;
        private Report _aktReport = new Report();
        private bool _zatmavit;
        public RelayCommand ZmenaUsekuCommand { get; private set; }
        public RelayCommand EditaceKontaktniOsobyCommand { get; private set; }
        public RelayCommand SpustitAplikaciCommand { get; private set; }

        public Uzivatel PrihlasenyUz
        {
            get { return _prihlasenyUz; }
            set
            {
                if (_prihlasenyUz != value)
                {
                    _prihlasenyUz = value;
                    OnPropertyChanged("PrihlasenyUz");
                }
            }
        }
        public KompetencniMatice.Models.KontaktniOsoba Kontakt
        {
            get { return _kontakt; }
            set
            {
                if (_kontakt != value)
                {
                    _kontakt = value;
                    OnPropertyChanged("Kontakt");
                }
            }
        }
        public Usek AktivniUsek
        {
            get { return _aktivniUsek; }
            set
            {
                if (_aktivniUsek != value)
                {
                    _aktivniUsek = value;
                    OnPropertyChanged("AktivniUsek");
                }
            }
        }
        public bool Zatmavit
        {
            get { return _zatmavit; }
            set
            {
                if (_zatmavit != value)
                {
                    _zatmavit = value;
                    OnPropertyChanged("Zatmavit");
                }
            }
        }
        public Report AktReport
        {
            get { return _aktReport; }
            set
            {
                if (_aktReport != value)
                {
                    _aktReport = value;
                    OnPropertyChanged("AktReport");
                }
            }
        }
        public MainWindowViewModel()
        {
            Task.Run(() =>
            {
                PrihlasenyUz = ActiveDirectory.VyhledejUzivatelePodleNT("fip8jh");
                PrihlasenyUz.seznamUseku = Usek.SelectUsekyPodleNT(PrihlasenyUz.ntUser);
                if (PrihlasenyUz.seznamUseku.Count > 0)
                {
                    AktivniUsek = PrihlasenyUz.seznamUseku.Where(d => d.id == Properties.Settings.Default.idUseku).FirstOrDefault();
                    if (AktivniUsek == null)
                    {
                        AktivniUsek = PrihlasenyUz.seznamUseku.FirstOrDefault();
                    }
                }
                PrihlasenyUz.kontaktniOsoba = KompetencniMatice.Models.KontaktniOsoba.HledejKontaktPodleNT();
                NactiReport();
            });
            ZmenaUsekuCommand = new RelayCommand(param => this.ZmenaUseku());
            EditaceKontaktniOsobyCommand = new RelayCommand(param => this.EditaceKontaktniOsoby());
            SpustitAplikaciCommand = new RelayCommand(param => this.SpustitAplikaci());
        }

        private void ZmenaUseku()
        {
            Properties.Settings.Default.idUseku = AktivniUsek.id;
            Properties.Settings.Default.Save();
            Task.Run(() =>
            {
                NactiReport();
            });
        }
        private void EditaceKontaktniOsoby()
        {
            Zatmavit = true;
            Kontakt = new KompetencniMatice.Models.KontaktniOsoba();
            Kontakt.jmeno = PrihlasenyUz.kontaktniOsoba.jmeno;
            Kontakt.oddeleni = PrihlasenyUz.kontaktniOsoba.oddeleni;
            Kontakt.stredisko = PrihlasenyUz.kontaktniOsoba.stredisko;
            Kontakt.usek = PrihlasenyUz.kontaktniOsoba.usek;
            Kontakt.zavod = PrihlasenyUz.kontaktniOsoba.zavod;
            Kontakt.hala = PrihlasenyUz.kontaktniOsoba.hala;
            Kontakt.vchod = PrihlasenyUz.kontaktniOsoba.vchod;
            Kontakt.mistoVyzvednuti = PrihlasenyUz.kontaktniOsoba.mistoVyzvednuti;
            Kontakt.pozice = PrihlasenyUz.kontaktniOsoba.pozice;
            Kontakt.smenovyModel = PrihlasenyUz.kontaktniOsoba.smenovyModel;
            Kontakt.mobil = PrihlasenyUz.kontaktniOsoba.mobil;
            Kontakt.klapka = PrihlasenyUz.kontaktniOsoba.klapka;
            Kontakt.uzivatel = PrihlasenyUz.kontaktniOsoba.uzivatel;
            Kontakt.email = PrihlasenyUz.kontaktniOsoba.email;
            EditaceKontaktniOsobyWindow editace = new EditaceKontaktniOsobyWindow();
            editace.DataContext = this;
            editace.Owner = Application.Current.MainWindow;
            editace.ShowDialog();
            if (editace.ulozit)
            {
                PrihlasenyUz.kontaktniOsoba = Kontakt;
                KompetencniMatice.Models.KontaktniOsoba.UpravitKontaktniOsobu(Kontakt);
            }
            
            Zatmavit = false;
        }
        private void NactiReport()
        {
            AktReport.pocetZam = AktivniUsek.pocetZam;
            AktReport.pocetZaskolovanych = Zamestnanec.PocetOtevrenychZaskoleni(AktivniUsek.id);
            AktReport.pocetInzeratu = KompetencniMatice.Models.Inzerat.PocetOtevrenychInzeratu();
            AktReport.pocetMychInzeratu = KompetencniMatice.Models.Inzerat.PocetOtevrenychMychInzeratu("fip8jh");
            AktReport.pocetZapujcenychZam = KompetencniMatice.Models.Zamestnanec.PocetZapujcenychZam(AktivniUsek.id);
        }
        private void SpustitAplikaci()
        {
            Zatmavit = true;
            eTraining.Helpers.ErrorWindow oknoChyba = new eTraining.Helpers.ErrorWindow();
            oknoChyba.TextVarovani = "Aplikace je nedostupná!";
            oknoChyba.Owner = Application.Current.MainWindow;
            oknoChyba.ShowDialog();
            Zatmavit = false;
        }
    }
}

