﻿using Support;
using KompetencniMatice.ViewModels;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data.SqlClient;
using System.Linq;
using System.Windows;

namespace KompetencniMatice.Models
{
    public class OblastVyroby: ViewModelBase
    {
        public int id { get; set; }
        private string _nazev;
        private int _idTypu;
        public int idUseku { get; set; }
        public string nazevUseku { get; set; }
        private string _barva;
        private ObservableCollection<Pracoviste> _seznamPracovist;
        private bool _zobrazit = true;
        public string nazev
        {
            get { return _nazev; }
            set
            {
                if (_nazev != value)
                {
                    _nazev = value;
                    OnPropertyChanged("nazev");
                }
            }
        }
        public int idTypu
        {
            get { return _idTypu; }
            set
            {
                if (_idTypu != value)
                {
                    _idTypu = value;
                    OnPropertyChanged("idTypu");
                }
            }
        }
        public string barva
        {
            get { return _barva; }
            set
            {
                if (_barva != value)
                {
                    _barva = value;
                    OnPropertyChanged("barva");
                }
            }
        }
        public ObservableCollection<Pracoviste> seznamPracovist
        {
            get { return _seznamPracovist; }
            set
            {
                if (_seznamPracovist != value)
                {
                    _seznamPracovist = value;
                    OnPropertyChanged("seznamPracovist");
                }
            }
        }
        public bool zobrazit
        {
            get { return _zobrazit; }
            set
            {
                if (_zobrazit != value)
                {
                    _zobrazit = value;
                    OnPropertyChanged("zobrazit");
                }
            }
        }
        public static ObservableCollection<OblastVyroby> SelectOblastiVyrobyUseku()
        {
            ObservableCollection<OblastVyroby> seznam = new ObservableCollection<OblastVyroby>();
            
            String sqlStr = "SELECT id, nazev, idTypu, barva FROM Matice_OblastVyroby WHERE idUseku = " + Properties.Settings.Default.idUseku;

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);
                    SqlDataReader reader = cmd.ExecuteReader();
                    OblastVyroby item;

                    while (reader.Read())
                    {
                        item = new OblastVyroby();
                        item.id = reader.GetInt32(0);
                        item.nazev = reader.GetValue(1).ToString();
                        item.idTypu = reader.GetInt32(2);
                        item.barva = reader.GetValue(3).ToString();
                        item.zobrazit = false;

                        seznam.Add(item);
                    }

                    cmd.Dispose();

                }

                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
            }
            return seznam;
        }
        public static ObservableCollection<OblastVyroby> SelectVsechnyOblastiVyrobyZam(IEnumerable<int> seznamOblasti)
        {
            ObservableCollection<OblastVyroby> seznam = new ObservableCollection<OblastVyroby>();
            if (seznamOblasti.Count() == 0) return seznam;

            string sqlStr = "SELECT a.id, a.nazev, a.idTypu, a.barva, b.id, b.nazev FROM Matice_OblastVyroby AS a "
                + "JOIN Usek AS b ON a.idUseku = b.id "
                + "WHERE a.id IN (";
            foreach (var item in seznamOblasti)
            {
                sqlStr += item + ", ";
            }
            sqlStr = sqlStr.Remove(sqlStr.Length - 2);
            sqlStr += " ) ";


            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);
                    SqlDataReader reader = cmd.ExecuteReader();
                    OblastVyroby item;

                    while (reader.Read())
                    {
                        item = new OblastVyroby();
                        item.id = reader.GetInt32(0);
                        item.nazev = reader.GetValue(1).ToString();
                        item.idTypu = reader.GetInt32(2);
                        item.barva = reader.GetValue(3).ToString();
                        item.idUseku = reader.GetInt32(4);
                        item.nazevUseku = reader.GetValue(5).ToString();
                        seznam.Add(item);
                    }

                    cmd.Dispose();

                }

                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
            }
            return seznam;
        }
        public static OblastVyroby VlozitOblast(OblastVyroby oblast)
        {
            String sqlStr = "UPDATE Matice_OblastVyroby SET nazev=@nazev, idTypu=@idTypu, idUseku=@idUseku, barva=@barva WHERE id = " + oblast.id
                        + " IF @@ROWCOUNT=0 INSERT INTO Matice_OblastVyroby (nazev, idTypu, idUseku, barva) VALUES (@nazev, @idTypu, @idUseku, @barva) SELECT SCOPE_IDENTITY();";

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);

                    cmd.Parameters.AddWithValue("@nazev", oblast.nazev);
                    cmd.Parameters.AddWithValue("@idTypu", oblast.idTypu);
                    cmd.Parameters.AddWithValue("@idUseku", Properties.Settings.Default.idUseku);
                    cmd.Parameters.AddWithValue("@barva", oblast.barva);

                    if (oblast.id != 0)
                    {
                        cmd.ExecuteNonQuery();
                    }
                    else oblast.id = Convert.ToInt32(cmd.ExecuteScalar());

                    cmd.Dispose();

                }


                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
                return oblast;
            }
        }

        public static bool SmazatOblast(int idOblasti)
        {
            String sqlStr = "DELETE FROM Matice_OblastVyroby WHERE id = " + idOblasti
                + " DELETE FROM Matice_OblastVyroby WHERE idMasky = " + idOblasti;

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);

                    cmd.ExecuteNonQuery();
                    cmd.Dispose();
                }


                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                    return false;
                }
                finally
                {
                    conn.Close();
                }
                return true;
            }
        }
    }
}
