﻿using Support;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data.SqlClient;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace KompetencniMatice.Models
{
    public class Pracoviste
    {
        public int id { get; set; }
        public string nazev { get; set; }
        public int idOblasti { get; set; }
        public Kompetentce kompetence { get; set; }

        public Pracoviste()
        {
            kompetence = new Kompetentce();
        }
        public static ObservableCollection<Pracoviste> SelectPracovisteZamestnanceUseku(Zamestnanec zam)
        {
            ObservableCollection<Pracoviste> seznam = new ObservableCollection<Pracoviste>();

            String sqlStr = "SELECT a.id, a.idOblasti, a.nazev, d.hodnoceni, d.idTridy FROM Matice_Pracoviste AS a "
                + "JOIN Matice_OblastVyroby AS b ON a.idOblasti = b.id "
                + "JOIN Zamestnanec AS c ON (c.idUseku = b.idUseku OR c.idZapujcenehoUseku = b.idUseku)"
                //if (zam.idZapujcenehoUseku != 0) sqlStr += "JOIN Zamestnanec AS c ON c.idZapujcenehoUseku = b.idUseku ";
                //else sqlStr += "JOIN Zamestnanec AS c ON c.idUseku = b.idUseku ";

                + "LEFT JOIN Matice_Kompetence AS d ON (d.idZam = c.id AND d.idPracoviste = a.id) "
                + "WHERE b.idUseku = " + Properties.Settings.Default.idUseku + " AND c.id = " + zam.id;

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);
                    SqlDataReader reader = cmd.ExecuteReader();
                    Pracoviste item;

                    while (reader.Read())
                    {
                        item = new Pracoviste();
                        item.id = reader.GetInt32(0);
                        item.idOblasti = reader.GetInt32(1);
                        item.nazev = reader.GetValue(2).ToString();
                        if (reader.GetValue(3) != DBNull.Value)
                        {
                            item.kompetence.hodnoceni = reader.GetInt32(3);
                            item.kompetence.idTridy = reader.GetInt32(4);
                        }
                        else item.kompetence.hodnoceni = null;
                        item.kompetence.idPracoviste = item.id;
                        item.kompetence.idZam = zam.id;
                        item.kompetence.ulozitTridu = true;
                        seznam.Add(item);
                    }

                    cmd.Dispose();

                }

                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
            }
            return seznam;
        }
        public static ObservableCollection<Pracoviste> SelectPracovisteUseku()
        {
            ObservableCollection<Pracoviste> seznam = new ObservableCollection<Pracoviste>();

            String sqlStr = "SELECT a.id, a.nazev, a.idOblasti FROM Matice_Pracoviste AS a "
                + "JOIN Matice_OblastVyroby AS b ON a.idOblasti = b.id "
                + "WHERE b.idUseku = " + Properties.Settings.Default.idUseku;

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);
                    SqlDataReader reader = cmd.ExecuteReader();
                    Pracoviste pracoviste;

                    while (reader.Read())
                    {
                        pracoviste = new Pracoviste();
                        pracoviste.id = reader.GetInt32(0);
                        pracoviste.nazev = reader.GetValue(1).ToString();
                        pracoviste.idOblasti = reader.GetInt32(2);
                        seznam.Add(pracoviste);
                    }

                    cmd.Dispose();

                }

                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
            }
            return seznam;
        }

        public static ObservableCollection<Pracoviste> SelectPracovisteOblasti(ObservableCollection<OblastVyroby> seznamOblasti)
        {
            ObservableCollection<Pracoviste> seznam = new ObservableCollection<Pracoviste>();
            if (seznamOblasti == null || seznamOblasti.Count == 0) return seznam;

            String sqlStr = "SELECT id, nazev, idOblasti FROM Matice_Pracoviste WHERE "
                + " idOblasti IN (";

            foreach (var item in seznamOblasti)
            {
                sqlStr += "'" + item.id + "',";
            }
            sqlStr = sqlStr.Remove(sqlStr.Length - 1);
            sqlStr += " )"

            + " ORDER BY nazev";

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd = new SqlCommand(sqlStr, conn);
                    SqlDataReader reader = cmd.ExecuteReader();
                    Pracoviste pracoviste;

                    while (reader.Read())
                    {
                        pracoviste = new Pracoviste();
                        pracoviste.id = reader.GetInt32(0);
                        pracoviste.nazev = reader.GetValue(1).ToString();
                        pracoviste.idOblasti = reader.GetInt32(2);

                        seznam.Add(pracoviste);
                    }

                    cmd.Dispose();

                }

                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
            }
            return seznam;
        }

        public static ObservableCollection<Pracoviste> VlozitPracoviste(ObservableCollection<Pracoviste> seznam, int idOblasti)
        {
            String sqlStr;

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd;
                    foreach (Pracoviste item in seznam)
                    {

                        sqlStr = "UPDATE Matice_Pracoviste SET nazev=@nazev, idOblasti=@idOblasti WHERE id = " + item.id
                        + " IF @@ROWCOUNT=0 INSERT INTO Matice_Pracoviste (nazev, idOblasti) VALUES (@nazev, @idOblasti) SELECT SCOPE_IDENTITY();";
                        cmd = new SqlCommand(sqlStr, conn);

                        cmd.Parameters.Clear();
                        cmd.Parameters.AddWithValue("@nazev", item.nazev);
                        cmd.Parameters.AddWithValue("@idOblasti", idOblasti);

                        if (item.id != 0)
                        {
                            cmd.ExecuteNonQuery();
                        }
                        else item.id = Convert.ToInt32(cmd.ExecuteScalar());
                        cmd.Dispose();
                    }
                }


                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                }
                finally
                {
                    conn.Close();
                }
                return seznam;
            }
        }
        public static bool SmazatPracoviste(ObservableCollection<Pracoviste> seznam)
        {
            String sqlStr;

            using (SqlConnection conn = new SqlConnection(ConnectionString.connectionString))
            {
                try
                {
                    conn.Open();
                    SqlCommand cmd;
                    foreach (Pracoviste item in seznam)
                    {

                        sqlStr = "DELETE FROM Matice_Pracoviste WHERE id = " + item.id;

                        cmd = new SqlCommand(sqlStr, conn);

                        cmd.Parameters.Clear();
                        cmd.ExecuteNonQuery();
                        cmd.Dispose();
                    }
                }


                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message, "Problém s připojením");
                    return false;
                }
                finally
                {
                    conn.Close();
                }
                return true;
            }
        }
    }
}
