﻿using KompetencniMatice.Commands;
using KompetencniMatice.Helpers;
using KompetencniMatice.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace KompetencniMatice.ViewModels.ReportVM
{
    class PrehledViewModel : ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZpet Zpet = delegate { };
        public class ZobrazenePracoviste : Pracoviste, INotifyPropertyChanged
        {
            #region INotifyPropertyChanged members

            public event PropertyChangedEventHandler PropertyChanged;
            protected void OnPropertyChanged(string propertyName)
            {
                PropertyChangedEventHandler handler = this.PropertyChanged;
                if (handler != null)
                {
                    var e = new PropertyChangedEventArgs(propertyName);
                    handler(this, e);
                }
            }

            #endregion
            public bool zobrazit { get; set; }
            public string barva { get; set; }
            private bool _pouzityFiltr;
            private bool[] _filtr;
            public bool pouzityFiltr
            {
                get { return _pouzityFiltr; }
                set { _pouzityFiltr = value; OnPropertyChanged("pouzityFiltr"); }
            }
            public bool[] filtr
            {
                get { return _filtr; }
                set { _filtr = value; OnPropertyChanged("filtr"); }
            }
        }
        public class ZobrazeneSmeny : SmenovyModel
        {
            public bool zobrazit { get; set; }
        }
        public class DataProVyber : ViewModelBase
        {
            private ObservableCollection<ZobrazeneSmeny> _smenoveModelyProVyber = new ObservableCollection<ZobrazeneSmeny>();
            private ObservableCollection<OblastVyroby> _oblastiProVyber;
            private ObservableCollection<ZobrazenePracoviste> _pracovisteProVyber = new ObservableCollection<ZobrazenePracoviste>();

            public ObservableCollection<ZobrazeneSmeny> SmenoveModelyProVyber
            {
                get { return _smenoveModelyProVyber; }
                set
                {
                    if (_smenoveModelyProVyber != value)
                    {
                        _smenoveModelyProVyber = value;
                        OnPropertyChanged("SmenoveModelyProVyber");
                    }
                }
            }
            public ObservableCollection<OblastVyroby> OblastiProVyber
            {
                get { return _oblastiProVyber; }
                set
                {
                    if (_oblastiProVyber != value)
                    {
                        _oblastiProVyber = value;
                        OnPropertyChanged("OblastiProVyber");
                    }
                }
            }
            public ObservableCollection<ZobrazenePracoviste> PracovisteProVyber
            {
                get { return _pracovisteProVyber; }
                set
                {
                    if (_pracovisteProVyber != value)
                    {
                        _pracovisteProVyber = value;
                        OnPropertyChanged("PracovisteProVyber");
                    }
                }
            }
        }

        private ObservableCollection<Pracoviste> seznamHodnoceni;
        private ObservableCollection<Zamestnanec> seznamZamVse;
        private ObservableCollection<Pracoviste> seznamHodnoceniVse;

        private DataProVyber _vyber;
        private bool _isBusy;
        private bool _zobrazeneZadani = true;
        private bool _zadnaData;
        private ObservableCollection<Zamestnanec> _seznamZam;
        private List<string> _obsahCB;
        public RelayCommand<OblastVyroby> PridatOdebratPracovisteCommand { get; private set; }
        public RelayCommand ZobrazitCommand { get; private set; }
        public RelayCommand<int> ZrusitVyberCommand { get; private set; }
        public RelayCommand<int> FiltrStanicCommand { get; private set; }
        public RelayCommand ZavriZadaniCommand { get; private set; }
        public string Name
        {
            get
            {
                return "Přehled";
            }
        }

        public DataProVyber Vyber
        {
            get { return _vyber; }
            set
            {
                if (_vyber != value)
                {
                    _vyber = value;
                    OnPropertyChanged("Vyber");
                }
            }
        }

        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public bool ZobrazeneZadani
        {
            get { return _zobrazeneZadani; }
            set
            {
                if (_zobrazeneZadani != value)
                {
                    _zobrazeneZadani = value;
                    OnPropertyChanged("ZobrazeneZadani");
                }
            }
        }
        public bool ZadnaData
        {
            get { return _zadnaData; }
            set
            {
                if (_zadnaData != value)
                {
                    _zadnaData = value;
                    OnPropertyChanged("ZadnaData");
                }
            }
        }
        public ObservableCollection<Zamestnanec> SeznamZam
        {
            get { return _seznamZam; }
            set
            {
                if (_seznamZam != value)
                {
                    _seznamZam = value;
                    OnPropertyChanged("SeznamZam");
                }
            }
        }
        public List<string> ObsahCB
        {
            get { return _obsahCB; }
            set
            {
                if (_obsahCB != value)
                {
                    _obsahCB = value;
                    OnPropertyChanged("ObsahCB");
                }
            }
        }
        public PrehledViewModel()
        {

            PridatOdebratPracovisteCommand = new RelayCommand<OblastVyroby>(param => this.PridatOdebratPracoviste(param));
            ZobrazitCommand = new RelayCommand(param => this.Zobrazit());
            ZavriZadaniCommand = new RelayCommand(param => this.ZavriZadani());
            ZrusitVyberCommand = new RelayCommand<int>(param => this.ZrusitVyber(param));
            FiltrStanicCommand = new RelayCommand<int>(param => this.FiltrStanic(param));
            NactiDataProCB();
        }

        private void NactiDataProCB()
        {
            Task.Run(() =>
            {
                IsBusy = true;
                Vyber = new DataProVyber();
                ObsahCB = new List<string> { "-", "●●", "●o", "oo", "●●●", "●●o", "●oo", "ooo" };
                foreach (var item in SmenovyModel.SelectSmenoveModelyProCB())
                {
                    App.Current.Dispatcher.Invoke((Action)delegate
                    {
                        Vyber.SmenoveModelyProVyber.Add(new ZobrazeneSmeny { id = item.id, nazev = item.nazev, zobrazit = true });
                    });
                }
                Vyber.OblastiProVyber = OblastVyroby.SelectOblastiVyrobyUseku();
                ObservableCollection<Pracoviste> seznamPrac = Pracoviste.SelectPracovisteUseku();
                foreach (var item in Vyber.OblastiProVyber)
                {
                    item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPrac.Where(d => d.idOblasti == item.id));
                }
                IsBusy = false;
            });
        }

        private void PridatOdebratPracoviste(OblastVyroby oblast)
        {
            if (oblast.zobrazit)
            {
                foreach (var item in oblast.seznamPracovist)
                {
                    Vyber.PracovisteProVyber.Add(new ZobrazenePracoviste { id = item.id, idOblasti = item.id, nazev = item.nazev, zobrazit = true, barva = oblast.barva, filtr = new bool[8] { true, true, true, true, true, true, true, true } });
                }
            }
            else
            {
                foreach (var item in oblast.seznamPracovist)
                {
                    Vyber.PracovisteProVyber.Remove(Vyber.PracovisteProVyber.Where(d => d.id == item.id).FirstOrDefault());
                }
            }
        }

        private void Zobrazit()
        {
            ZobrazeneZadani = false;
            Vyber.PracovisteProVyber = new ObservableCollection<ZobrazenePracoviste>(Vyber.PracovisteProVyber.OrderBy(d => d.kompetence.idPracoviste));
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamZam = Zamestnanec.SelectZam(Properties.Settings.Default.idUseku);
                seznamHodnoceniVse = Kompetentce.SelectKompetenceVsechDaneOblasti(Vyber.PracovisteProVyber.Select(d=>d.id).ToList());
                foreach (var item in SeznamZam)
                {
                    item.zobrazenaOblastVyroby = new OblastVyroby();
                    //item.ZobrazenaOblastVyroby = VybranaOblastProZobrazeni;
                    item.zobrazenaOblastVyroby.seznamPracovist = new ObservableCollection<Pracoviste>(seznamHodnoceniVse.Where(d => d.kompetence.idZam == item.id).OrderBy(d=>d.kompetence.idPracoviste));
                }
                seznamZamVse = new ObservableCollection<Zamestnanec>(SeznamZam);
                IsBusy = false;
            });
        }
        private void ZrusitVyber(int idPracoviste)
        {
            Vyber.PracovisteProVyber.Where(d => d.id == idPracoviste).FirstOrDefault().filtr = new bool[8] { false, false, false, false, false, false, false, false };
            //for (int i = 0; i< Vyber.PracovisteProVyber.Where(d => d.id == idPracoviste).FirstOrDefault().filtr.Count(); i++)
            //{
            //    Vyber.PracovisteProVyber.Where(d => d.id == idPracoviste).FirstOrDefault().filtr[i] = false;
            //}       
        }
        private void FiltrStanic(int idPracoviste)
        {
            SeznamZam = new ObservableCollection<Zamestnanec>(seznamZamVse);
            //ZobrazenePracoviste pracoviste = Vyber.PracovisteProVyber.Where(d => d.id == idPracoviste).FirstOrDefault();
            seznamHodnoceni = new ObservableCollection<Pracoviste>(seznamHodnoceniVse);
            foreach (var prac in Vyber.PracovisteProVyber)
            {
                prac.pouzityFiltr = false;
                for (int i = 0; i < prac.filtr.Length; i++)
                {
                    
                    if (!prac.filtr[i])
                    {
                        prac.pouzityFiltr = true;
                        switch (i)
                        {
                            case 0:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "-" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }

                                break;
                            case 1:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "●●" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            case 2:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "●o" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            case 3:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "oo" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            case 4:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "●●●" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            case 5:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "●●o" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            case 6:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "●oo" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            case 7:
                                foreach (var item in seznamHodnoceni.Where(d => d.kompetence.prehled == "ooo" && d.kompetence.idPracoviste == prac.id).Select(d => d.kompetence.idZam).Distinct())
                                {
                                    SeznamZam.Remove(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                                }
                                break;
                            default:
                                break;
                        }
                    }
                }
            }
            
            
            //PriraditZamKeKompetencim();
        }

        private void PriraditZamKeKompetencim()
        {
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamZam = new ObservableCollection<Zamestnanec>();
                foreach (var item in seznamHodnoceni.Select(d=>d.kompetence.idZam).Distinct())
                {
                    SeznamZam.Add(seznamZamVse.Where(d => d.id == item).FirstOrDefault());
                }
                foreach (var item in SeznamZam)
                {
                    item.zobrazenaOblastVyroby = new OblastVyroby();
                    //item.ZobrazenaOblastVyroby = VybranaOblastProZobrazeni;
                    item.zobrazenaOblastVyroby.seznamPracovist = new ObservableCollection<Pracoviste>(seznamHodnoceniVse.Where(d => d.kompetence.idZam == item.id));
                }
                IsBusy = false;
            });
        }

        private void ZavriZadani()
        {
            Zpet();
        }

    }
}


