﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using KompetencniMatice.Helpers;
using KompetencniMatice.Models;
using System.Collections.ObjectModel;
using KompetencniMatice.Commands;

namespace KompetencniMatice.ViewModels.ZamVM
{
    class DetailZamViewModel : ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZpet Zpet = delegate { };
        private ObservableCollection<OblastVyroby> seznamOblastiVse;

        private ObservableCollection<Pracoviste> seznamPracovist;
        private bool _isBusy;
        private Zamestnanec _zam;
        private Usek _aktualniUsek;
        private bool _editace = true;
        private ObservableCollection<Usek> _seznamUseku;
        private ObservableCollection<OblastVyroby> _seznamOblasti;
        private ObservableCollection<Trida> _seznamTridCB;
        private ObservableCollection<Inzerat> _seznamHistorie;
        public RelayCommand<int> ZmenaUsekuCommand { get; private set; }
        public RelayCommand ZmenaUsekuNaAktualniCommand { get; private set; }
        public RelayCommand ZpetNaUvodCommand { get; private set; }
        public string Name
        {
            get
            {
                return "DetailView";
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public Zamestnanec Zam
        {
            get { return _zam; }
            set
            {
                if (_zam != value)
                {
                    _zam = value;
                    NactiData();
                    OnPropertyChanged("Zam");
                }
            }
        }
        public Usek AktualniUsek
        {
            get { return _aktualniUsek; }
            set
            {
                if (_aktualniUsek != value)
                {
                    _aktualniUsek = value;
                    OnPropertyChanged("AktualniUsek");
                }
            }
        }
        public bool Editace
        {
            get { return _editace; }
            set
            {
                if (_editace != value)
                {
                    _editace = value;
                    OnPropertyChanged("Editace");
                }
            }
        }
        public ObservableCollection<OblastVyroby> SeznamOblasti
        {
            get { return _seznamOblasti; }
            set
            {
                if (_seznamOblasti != value)
                {
                    _seznamOblasti = value;
                    OnPropertyChanged("SeznamOblasti");
                }
            }
        }
        public ObservableCollection<Trida> SeznamTridCB
        {
            get { return _seznamTridCB; }
            set
            {
                if (_seznamTridCB != value)
                {
                    _seznamTridCB = value;
                    OnPropertyChanged("SeznamTridCB");
                }
            }
        }
        public ObservableCollection<Usek> SeznamUseku
        {
            get { return _seznamUseku; }
            set
            {
                if (_seznamUseku != value)
                {
                    _seznamUseku = value;
                    OnPropertyChanged("SeznamUseku");
                }
            }
        }
        public ObservableCollection<Inzerat> SeznamHistorie
        {
            get { return _seznamHistorie; }
            set
            {
                if (_seznamHistorie != value)
                {
                    _seznamHistorie = value;
                    OnPropertyChanged("SeznamHistorie");
                }
            }
        }
        public DetailZamViewModel(Zamestnanec zamestnanec)
        {
            if (zamestnanec != null)
            {
                ZpetNaUvodCommand = new RelayCommand(param => this.ZpetNaUvod());
                ZmenaUsekuCommand = new RelayCommand<int>(param => this.ZmenaUseku(param));
                ZmenaUsekuNaAktualniCommand = new RelayCommand(param => this.ZmenaUsekuNaAktualni());

                Zam = zamestnanec;
            }
        }
        private void NactiData()
        {

            if (Zam != null)
            {
                
                Task.Run(() =>
                {
                    IsBusy = true;
                    SeznamTridCB = Trida.SelectTridyProCB();
                    SeznamUseku = Usek.SelectUsekyZam(Zam.id, Properties.Settings.Default.idUseku);
                    seznamPracovist = Kompetentce.SelectVsechnyKompetenceZam(Zam.id, Properties.Settings.Default.idUseku, SeznamUseku);
                    seznamOblastiVse = OblastVyroby.SelectVsechnyOblastiVyrobyZam(seznamPracovist.Select(d => d.idOblasti).Distinct());
                    SeznamOblasti = new ObservableCollection<OblastVyroby>(seznamOblastiVse.Where(d => d.idUseku == Properties.Settings.Default.idUseku).ToList());
                    foreach (var item in SeznamOblasti)
                    {
                        item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPracovist.Where(d => d.idOblasti == item.id).ToList());
                    }
                    foreach (var item in seznamOblastiVse.Where(d => d.idUseku == Properties.Settings.Default.idUseku).Select(d => new { d.idUseku, d.nazevUseku }).Distinct())
                    {
                        AktualniUsek = new Usek { id = item.idUseku, nazev = item.nazevUseku };
                    }
                    SeznamHistorie = Inzerat.SelectHistorieInzeratuZam(Zam.id);
                    IsBusy = false;
                });
            }
        }
        private void ZmenaUsekuNaAktualni()
        {
            Editace = true;
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamOblasti = new ObservableCollection<OblastVyroby>(seznamOblastiVse.Where(d => d.idUseku == Properties.Settings.Default.idUseku).ToList());
                foreach (var item in SeznamOblasti)
                {
                    item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPracovist.Where(d => d.idOblasti == item.id).ToList());
                }
                IsBusy = false;
            });
        }
        private void ZmenaUseku(int idUseku)
        {
            Editace = false;
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamOblasti = new ObservableCollection<OblastVyroby>(seznamOblastiVse.Where(d => d.idUseku == idUseku).ToList());
                foreach (var item in SeznamOblasti)
                {
                    item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPracovist.Where(d => d.idOblasti == item.id).ToList());
                }
                IsBusy = false;
            });
        }
        private void ZpetNaUvod()
        {
            Zpet();
        }
    }
}
