﻿using KompetencniMatice.Commands;
using KompetencniMatice.Helpers;
using KompetencniMatice.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
namespace KompetencniMatice.ViewModels.ZamVM
{
    class ZadaniZamViewModel : ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZpet Zpet = delegate { };
        public static event EventHandlerZpetSNovymZam ZpetSeZam = delegate { };

        private bool update;
        private Zamestnanec _zam;
        private bool _chyba;
        private string _chybaPopis;
        ObservableCollection<SmenovyModel> _smenoveModelyProVyber;
        ObservableCollection<Pozice> _poziceProVyber;
        private bool _isBusy;

        public RelayCommand UlozitCommand { get; private set; }
        public RelayCommand ZavriZadaniCommand { get; private set; }
        public string Name
        {
            get
            {
                return "Zadani";
            }
        }
        public Zamestnanec Zam
        {
            get { return _zam; }
            set
            {
                if (_zam != value)
                {
                    _zam = value;
                    OnPropertyChanged("Zam");
                }
            }
        }
        public bool Chyba
        {
            get { return _chyba; }
            set
            {
                if (_chyba != value)
                {
                    _chyba = value;
                    OnPropertyChanged("Chyba");
                }
            }
        }
        public string ChybaPopis
        {
            get { return _chybaPopis; }
            set
            {
                if (_chybaPopis != value)
                {
                    _chybaPopis = value;
                    OnPropertyChanged("ChybaPopis");
                }
            }
        }
        public ObservableCollection<SmenovyModel> SmenoveModelyProVyber
        {
            get { return _smenoveModelyProVyber; }
            set
            {
                if (_smenoveModelyProVyber != value)
                {
                    _smenoveModelyProVyber = value;
                    OnPropertyChanged("SmenoveModelyProVyber");
                }
            }
        }
        public ObservableCollection<Pozice> PoziceProVyber
        {
            get { return _poziceProVyber; }
            set
            {
                if (_poziceProVyber != value)
                {
                    _poziceProVyber = value;
                    OnPropertyChanged("PoziceProVyber");
                }
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public ZadaniZamViewModel()
        {
            update = false;
            Zam = new Zamestnanec();
            Zam.datumNastupu = DateTime.Now;
            NactiDataProCB();
            UlozitCommand = new RelayCommand(param => this.Ulozit());
            ZavriZadaniCommand = new RelayCommand(param => this.ZavriZadani());
        }
        public ZadaniZamViewModel(Zamestnanec zamestnanec)
        {
            update = true;
            Zam = zamestnanec;
            NactiDataProCB();
            UlozitCommand = new RelayCommand(param => this.Ulozit());
            ZavriZadaniCommand = new RelayCommand(param => this.ZavriZadani());
            
        }
        private void NactiDataProCB()
        {
            Task.Run(() =>
            {
                IsBusy = true;
                SmenoveModelyProVyber = SmenovyModel.SelectSmenoveModelyProCB();
                PoziceProVyber = Pozice.SelectPoziceProCB();
                IsBusy = false;
            });
        }

        private void Ulozit()
        {
            if (Kontrola())
            {
                if (update)
                {
                    if (!Zamestnanec.EditaceZamestnanece(Zam))
                    {
                        Task.Run(() =>
                        {
                            Chyba = true;
                            ChybaPopis = "Nastala chyba při ukládání";
                            System.Threading.Thread.Sleep(2000);
                            Chyba = false;
                        });
                    }
                    else
                    {
                        ZavriZadani();
                    }
                }
                else
                {
                    Zam.id = Zamestnanec.VlozitZamestnance(Zam);

                    if (Zam.id == 0)
                    {
                        Task.Run(() =>
                        {
                            Chyba = true;
                            ChybaPopis = "Nastala chyba při ukládání";
                            System.Threading.Thread.Sleep(2000);
                            Chyba = false;
                        });
                    }
                    else
                    {
                        IsBusy = true;
                        eTraining.Models.CheckListZam.VlozitPrvniDataProKartu(eTraining.Models.CheckListZam.SelectCheckListProNovehoZam(Zam.id));
                        eTraining.Models.Hodnoceni.VlozitPrvniHodnoceni(Zam.id);
                        IsBusy = false;
                        ZavriZadaniSeZam();
                    }
                }
            }
            else
            {
                Task.Run(() =>
                {
                    Chyba = true;
                    System.Threading.Thread.Sleep(3000);
                    Chyba = false;
                });
            }
        }
        private bool Kontrola()
        {
            if (String.IsNullOrEmpty(Zam.osCislo))
            {
                ChybaPopis = "Vyplňte os. číslo";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.jmeno))
            {
                ChybaPopis = "Vyplňte jméno";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.prijmeni))
            {
                ChybaPopis = "Vyplňte příjmení";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.stredisko))
            {
                ChybaPopis = "Vyplňte středisko";
                return false;
            }
            if (Zam.datumNastupu < new DateTime(1900, 1, 1))
            {
                ChybaPopis = "Vyplňte platné datum nástupu";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.pohlavi))
            {
                ChybaPopis = "Vyberte pohlaví";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.smenovyModel))
            {
                ChybaPopis = "Vyberte směnový model";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.pozice))
            {
                ChybaPopis = "Vyberte pozici";
                return false;
            }
            if (!update && Zamestnanec.CheckZalozeni(Zam.osCislo, Zam.datumNastupu))
            {
                ChybaPopis = "Tento uživatel je již založen";
                return false;
            }
            return true;
        }
        private void ZavriZadani()
        {
            Zpet();
        }
        private void ZavriZadaniSeZam()
        {
            ZpetSeZam(Zam);
        }
    }
}

