﻿using KompetencniMatice.Commands;
using Nabidka.Helpers;
using KompetencniMatice.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Nabidka.DialogWindows;

namespace Nabidka.ViewModels.AdministraceVM
{
    class AdministraceCasuViewModel: ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZatmavit Zatmavit = delegate { };

        private bool editace = false;

        private bool _isBusy;
        private ObservableCollection<Cas> _seznamCasu;
        private Cas _novyCas;
        private Cas _vybranyCas;
        private bool _zobrazeniNovehoCasu = false;
        private string _nazev;

        public RelayCommand PridatCasCommand { get; private set; }
        public RelayCommand EditovatCasCommand { get; private set; }
        public RelayCommand UlozitCasCommand { get; private set; }
        public RelayCommand SmazatCasCommand { get; private set; }
        public RelayCommand ZavritCasCommand { get; private set; }

        public string Name
        {
            get
            {
                return "Administrace času";
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public ObservableCollection<Cas> SeznamCasu
        {
            get { return _seznamCasu; }
            set
            {
                if (_seznamCasu != value)
                {
                    _seznamCasu = value;
                    OnPropertyChanged("SeznamCasu");
                }
            }
        }
        public Cas NovyCas
        {
            get { return _novyCas; }
            set
            {
                if (_novyCas != value)
                {
                    _novyCas = value;
                    OnPropertyChanged("NovyCas");
                }
            }
        }
        public Cas VybranyCas
        {
            get { return _vybranyCas; }
            set
            {
                if (_vybranyCas != value)
                {
                    _vybranyCas = value;
                    OnPropertyChanged("VybranyCas");
                }
            }
        }
        public bool ZobrazeniNovehoCasu
        {
            get { return _zobrazeniNovehoCasu; }
            set
            {
                if (_zobrazeniNovehoCasu != value)
                {
                    _zobrazeniNovehoCasu = value;
                    OnPropertyChanged("ZobrazeniNovehoCasu");
                }
            }
        }
        public string Nazev
        {
            get { return _nazev; }
            set
            {
                if (_nazev != value)
                {
                    _nazev = value;
                    OnPropertyChanged("Nazev");
                }
            }
        }
        public AdministraceCasuViewModel()
        {
            
            PridatCasCommand = new RelayCommand(param => this.PridatCas());
            EditovatCasCommand = new RelayCommand(param => this.EditovatCas());
            UlozitCasCommand = new RelayCommand(param => this.UlozitCas());
            SmazatCasCommand = new RelayCommand(param => this.SmazatCas());
            ZavritCasCommand = new RelayCommand(param => this.ZavritCas());
            Nazev = "Aktuální seznam časů od/do";
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamCasu = Cas.SelectCasy();
                IsBusy = false;
            });
            
        }

        private void PridatCas()
        {
            editace = false;
            Nazev = "Nový čas";
            NovyCas = new Cas();
            ZobrazeniNovehoCasu = true;
        }
        private void EditovatCas()
        {
            editace = true;
            Nazev = "Editace času";
            NovyCas = new Cas(VybranyCas);
            ZobrazeniNovehoCasu = true;
        }
        private void UlozitCas()
        {
            Task.Run(() =>
            {
                if (!editace)
                {
                    NovyCas.id = Cas.VlozitCas(NovyCas);
                    App.Current.Dispatcher.Invoke((Action)delegate
                    {
                        SeznamCasu.Add(NovyCas);
                    });
                    
                    
                }
                else
                {
                    Cas.UpravitCas(NovyCas);
                    VybranyCas.cas = NovyCas.cas;
                }
                ZobrazeniNovehoCasu = false;
                Nazev = "Aktuální seznam časů od/do";
            });
        }
        private void SmazatCas()
        {
            Zatmavit(true);
            WarningWindow warninng = new WarningWindow();
            warninng.Owner = System.Windows.Application.Current.MainWindow;
            warninng.TextVarovani = "Opravdu chcete smazat tento čas?" + Environment.NewLine + "Data budou ztracena!!!";
            warninng.ShowDialog();
            if (warninng.OK)
            {
                Cas.SmazatCas(VybranyCas);
                App.Current.Dispatcher.Invoke((Action)delegate
                {
                    SeznamCasu.Remove(VybranyCas);
                });
            }
            Zatmavit(false);

        }
        private void ZavritCas()
        {
            ZobrazeniNovehoCasu = false;
            Nazev = "Aktuální seznam časů od/do";
        }

        
    }
}
