﻿using KompetencniMatice.Commands;
using Nabidka.Helpers;
using KompetencniMatice.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Nabidka.DialogWindows;

namespace Nabidka.ViewModels.AdministraceVM
{
    class AdministraceDuvoduViewModel : ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZatmavit Zatmavit = delegate { };

        private bool editace = false;

        private bool _isBusy;
        private ObservableCollection<Duvod> _seznamDuvoduNabidek;
        private ObservableCollection<Duvod> _seznamDuvoduPoptavek;
        private Duvod _novyDuvod;
        private Duvod _vybranyDuvod;
        private bool _zobrazeniNovehoDuvodu = false;
        private string _nazev;

        public RelayCommand<string> PridatDuvodCommand { get; private set; }
        public RelayCommand EditovatDuvodCommand { get; private set; }
        public RelayCommand UlozitDuvodCommand { get; private set; }
        public RelayCommand SmazatDuvodCommand { get; private set; }
        public RelayCommand ZavritDuvodCommand { get; private set; }

        public string Name
        {
            get
            {
                return "Administrace důvodů";
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public ObservableCollection<Duvod> SeznamDuvoduNabidek
        {
            get { return _seznamDuvoduNabidek; }
            set
            {
                if (_seznamDuvoduNabidek != value)
                {
                    _seznamDuvoduNabidek = value;
                    OnPropertyChanged("SeznamDuvoduNabidek");
                }
            }
        }
        public ObservableCollection<Duvod> SeznamDuvoduPoptavek
        {
            get { return _seznamDuvoduPoptavek; }
            set
            {
                if (_seznamDuvoduPoptavek != value)
                {
                    _seznamDuvoduPoptavek = value;
                    OnPropertyChanged("SeznamDuvoduPoptavek");
                }
            }
        }
        public Duvod NovyDuvod
        {
            get { return _novyDuvod; }
            set
            {
                if (_novyDuvod != value)
                {
                    _novyDuvod = value;
                    OnPropertyChanged("NovyDuvod");
                }
            }
        }
        public Duvod VybranyDuvod
        {
            get { return _vybranyDuvod; }
            set
            {
                if (_vybranyDuvod != value)
                {
                    _vybranyDuvod = value;
                    OnPropertyChanged("VybranyDuvod");
                }
            }
        }
        public bool ZobrazeniNovehoDuvodu
        {
            get { return _zobrazeniNovehoDuvodu; }
            set
            {
                if (_zobrazeniNovehoDuvodu != value)
                {
                    _zobrazeniNovehoDuvodu = value;
                    OnPropertyChanged("ZobrazeniNovehoDuvodu");
                }
            }
        }
        public string Nazev
        {
            get { return _nazev; }
            set
            {
                if (_nazev != value)
                {
                    _nazev = value;
                    OnPropertyChanged("Nazev");
                }
            }
        }
        public AdministraceDuvoduViewModel()
        {

            PridatDuvodCommand = new RelayCommand<String>(param => this.PridatDuvod(param));
            EditovatDuvodCommand = new RelayCommand(param => this.EditovatDuvod());
            UlozitDuvodCommand = new RelayCommand(param => this.UlozitDuvod());
            SmazatDuvodCommand = new RelayCommand(param => this.SmazatDuvod());
            ZavritDuvodCommand = new RelayCommand(param => this.ZavritDuvod());
            Nazev = "Aktuální seznamy důvodů nabídek a poptávek";
            Task.Run(() =>
            {
                IsBusy = true;
                ObservableCollection<Duvod> seznam = Duvod.SelectDuvody();
                SeznamDuvoduNabidek = new ObservableCollection<Duvod>(seznam.Where(d => d.nabidka).ToList());
                SeznamDuvoduPoptavek = new ObservableCollection<Duvod>(seznam.Where(d => !d.nabidka).ToList());
                IsBusy = false;
            });

        }

        private void PridatDuvod(string ktery)
        {
            editace = false;
            
            NovyDuvod = new Duvod();
            if (ktery == "nabidka")
            {
                Nazev = "Nový důvod nabídky";
                NovyDuvod.nabidka = true;
            }
            else
            {
                Nazev = "Nový důvod poptávky";
                NovyDuvod.nabidka = false;
            }
            ZobrazeniNovehoDuvodu = true;
        }
        private void EditovatDuvod()
        {
            editace = true;
            if (VybranyDuvod.nabidka) Nazev = "Editace důvodu nabídky";
            else Nazev = "Editace důvodu poptávky";

            NovyDuvod = new Duvod(VybranyDuvod);
            ZobrazeniNovehoDuvodu = true;
        }
        private void UlozitDuvod()
        {
            Task.Run(() =>
            {
                if (!editace)
                {
                    NovyDuvod.id = Duvod.VlozitDuvod(NovyDuvod);
                    if (NovyDuvod.nabidka)
                    {
                        App.Current.Dispatcher.Invoke((Action)delegate
                        {
                            SeznamDuvoduNabidek.Add(NovyDuvod);
                        });
                    }
                    else
                    {
                        App.Current.Dispatcher.Invoke((Action)delegate
                        {
                            SeznamDuvoduPoptavek.Add(NovyDuvod);
                        });
                    }


                }
                else
                {
                    Duvod.UpravitDuvod(NovyDuvod);
                    NovyDuvod.duvod = NovyDuvod.duvod;
                }
                ZobrazeniNovehoDuvodu = false;
                Nazev = "Aktuální seznamy důvodů nabídek a poptávek";
            });
        }
        private void SmazatDuvod()
        {
            Zatmavit(true);
            WarningWindow warninng = new WarningWindow();
            warninng.Owner = System.Windows.Application.Current.MainWindow;
            warninng.TextVarovani = "Opravdu chcete smazat tento důvod?" + Environment.NewLine + "Data budou ztracena!!!";
            warninng.ShowDialog();
            if (warninng.OK)
            {
                Duvod.SmazatDuvod(VybranyDuvod);
                if (VybranyDuvod.nabidka)
                {
                    App.Current.Dispatcher.Invoke((Action)delegate
                    {
                        SeznamDuvoduNabidek.Remove(VybranyDuvod);
                    });
                }
                else
                {
                    App.Current.Dispatcher.Invoke((Action)delegate
                    {
                        SeznamDuvoduPoptavek.Remove(VybranyDuvod);
                    });
                }
            }
            Zatmavit(false);

        }
        private void ZavritDuvod()
        {
            ZobrazeniNovehoDuvodu = false;
            Nazev = "Aktuální seznamy důvodů nabídek a poptávek";
        }


    }
}
