﻿using KompetencniMatice.Commands;
using Nabidka.Helpers;
using KompetencniMatice.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Nabidka.DialogWindows;

namespace Nabidka.ViewModels.AdministraceVM
{
    class AdministraceSmenViewModel : ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZatmavit Zatmavit = delegate { };

        private bool editace = false;

        private bool _isBusy;
        private ObservableCollection<SmenovyModel> _seznamSmen;
        private SmenovyModel _novaSmena;
        private SmenovyModel _vybranaSmena;
        private bool _zobrazeniNoveSmeny = false;
        private string _nazev;

        public RelayCommand PridatSmenuCommand { get; private set; }
        public RelayCommand EditovatSmenuCommand { get; private set; }
        public RelayCommand UlozitSmenuCommand { get; private set; }
        public RelayCommand SmazatSmenuCommand { get; private set; }
        public RelayCommand ZavritSmenuCommand { get; private set; }

        public string Name
        {
            get
            {
                return "Administrace směn";
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public ObservableCollection<SmenovyModel> SeznamSmen
        {
            get { return _seznamSmen; }
            set
            {
                if (_seznamSmen != value)
                {
                    _seznamSmen = value;
                    OnPropertyChanged("SeznamSmen");
                }
            }
        }
        public SmenovyModel NovaSmena
        {
            get { return _novaSmena; }
            set
            {
                if (_novaSmena != value)
                {
                    _novaSmena = value;
                    OnPropertyChanged("NovaSmena");
                }
            }
        }
        public SmenovyModel VybranaSmena
        {
            get { return _vybranaSmena; }
            set
            {
                if (_vybranaSmena != value)
                {
                    _vybranaSmena = value;
                    OnPropertyChanged("VybranaSmena");
                }
            }
        }
        public bool ZobrazeniNoveSmeny
        {
            get { return _zobrazeniNoveSmeny; }
            set
            {
                if (_zobrazeniNoveSmeny != value)
                {
                    _zobrazeniNoveSmeny = value;
                    OnPropertyChanged("ZobrazeniNoveSmeny");
                }
            }
        }
        public string Nazev
        {
            get { return _nazev; }
            set
            {
                if (_nazev != value)
                {
                    _nazev = value;
                    OnPropertyChanged("Nazev");
                }
            }
        }
        public AdministraceSmenViewModel()
        {

            PridatSmenuCommand = new RelayCommand(param => this.PridatSmenu());
            EditovatSmenuCommand = new RelayCommand(param => this.EditovatSmenu());
            UlozitSmenuCommand = new RelayCommand(param => this.UlozitSmenu());
            SmazatSmenuCommand = new RelayCommand(param => this.SmazatSmenu());
            ZavritSmenuCommand = new RelayCommand(param => this.ZavritSmenu());
            Nazev = "Aktuální seznam směnových modelů";
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamSmen = SmenovyModel.SelectSmenoveModelyProCB();
                IsBusy = false;
            });

        }

        private void PridatSmenu()
        {
            editace = false;
            Nazev = "Nový směnový model";
            NovaSmena = new SmenovyModel();
            ZobrazeniNoveSmeny = true;
        }
        private void EditovatSmenu()
        {
            editace = true;
            Nazev = "Editace směnového modelu";
            NovaSmena = new SmenovyModel(VybranaSmena);
            ZobrazeniNoveSmeny = true;
        }
        private void UlozitSmenu()
        {
            Task.Run(() =>
            {
                if (!editace)
                {
                    NovaSmena.id = SmenovyModel.VlozitSmenu(NovaSmena);
                    App.Current.Dispatcher.Invoke((Action)delegate
                    {
                        SeznamSmen.Add(NovaSmena);
                    });


                }
                else
                {
                    SmenovyModel.UpravitSmenu(NovaSmena);
                    VybranaSmena.nazev = NovaSmena.nazev;
                }
                ZobrazeniNoveSmeny = false;
                Nazev = "Aktuální seznam směnových modelů";
            });
        }
        private void SmazatSmenu()
        {
            Zatmavit(true);
            WarningWindow warninng = new WarningWindow();
            warninng.Owner = System.Windows.Application.Current.MainWindow;
            warninng.TextVarovani = "Opravdu chcete smazat tento směnový model?" + Environment.NewLine + "Data budou ztracena!!!";
            warninng.ShowDialog();
            if (warninng.OK)
            {
                SmenovyModel.SmazatSmenu(VybranaSmena);
                App.Current.Dispatcher.Invoke((Action)delegate
                {
                    SeznamSmen.Remove(VybranaSmena);
                });
            }
            Zatmavit(false);

        }
        private void ZavritSmenu()
        {
            ZobrazeniNoveSmeny = false;
            Nazev = "Aktuální seznam směnových modelů";
        }


    }
}
