﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using KompetencniMatice.Helpers;
using KompetencniMatice.Models;
using System.Collections.ObjectModel;
using KompetencniMatice.Commands;


namespace Nabidka.ViewModels.ZamestnanecVM
{
    class DetailZamViewModel : ViewModelBase
    {
        private ObservableCollection<Pracoviste> seznamPracovist;
        
        private ObservableCollection<OblastVyroby> seznamOblastiVse;
        private bool _isBusy;
        private Zamestnanec _zam;
        private Usek _aktualniUsek;

        private ObservableCollection<Usek> _seznamUseku;
        private ObservableCollection<OblastVyroby> _seznamOblasti;
        private ObservableCollection<Inzerat> _seznamHistorie;

        public RelayCommand<int> ZmenaUsekuCommand { get; private set; }
        public RelayCommand ZmenaUsekuNaAktualniCommand { get; private set; }
    public string Name
        {
            get
            {
                return "DetailView";
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public Zamestnanec Zam
        {
            get { return _zam; }
            set
            {
                if (_zam != value)
                {
                    _zam = value;
                    OnPropertyChanged("Zam");
                }
            }
        }
        public Usek AktualniUsek
        {
            get { return _aktualniUsek; }
            set
            {
                if (_aktualniUsek != value)
                {
                    _aktualniUsek = value;
                    OnPropertyChanged("AktualniUsek");
                }
            }
        }
        public ObservableCollection<OblastVyroby> SeznamOblasti
        {
            get { return _seznamOblasti; }
            set
            {
                if (_seznamOblasti != value)
                {
                    _seznamOblasti = value;
                    OnPropertyChanged("SeznamOblasti");
                }
            }
        }
        public ObservableCollection<Usek> SeznamUseku
        {
            get { return _seznamUseku; }
            set
            {
                if (_seznamUseku != value)
                {
                    _seznamUseku = value;
                    OnPropertyChanged("SeznamUseku");
                }
            }
        }

        public ObservableCollection<Inzerat> SeznamHistorie
        {
            get { return _seznamHistorie; }
            set
            {
                if (_seznamHistorie != value)
                {
                    _seznamHistorie = value;
                    OnPropertyChanged("SeznamHistorie");
                }
            }
        }
        public DetailZamViewModel(Zamestnanec zamestnanec)
        {
            ZmenaUsekuCommand = new RelayCommand<int>(param => this.ZmenaUseku(param));
            ZmenaUsekuNaAktualniCommand = new RelayCommand(param => this.ZmenaUsekuNaAktualni());
            if (zamestnanec != null)
            {
                Zam = zamestnanec;
                NactiData();
            }
        }
        private void NactiData()
        {
            if (Zam != null)
            {
                Task.Run(() =>
                {
                    IsBusy = true;

                    SeznamUseku = Usek.SelectUsekyZam(Zam.id, Zam.idUseku);
                    seznamPracovist = Kompetentce.SelectVsechnyKompetenceZam(Zam.id, Zam.idUseku, SeznamUseku);
                    seznamOblastiVse = OblastVyroby.SelectVsechnyOblastiVyrobyZam(seznamPracovist.Select(d => d.idOblasti).Distinct());
                    SeznamOblasti = new ObservableCollection<OblastVyroby>(seznamOblastiVse.Where(d => d.idUseku == Zam.idUseku).ToList());
                    foreach (var item in SeznamOblasti)
                    {
                        item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPracovist.Where(d => d.idOblasti == item.id).ToList());
                    }
                    foreach (var item in seznamOblastiVse.Where(d => d.idUseku == Zam.idUseku).Select(d => new { d.idUseku, d.nazevUseku }).Distinct())
                    {
                        AktualniUsek = new Usek { id = item.idUseku, nazev = item.nazevUseku };
                    }
                    SeznamHistorie = Inzerat.SelectHistorieInzeratuZam(Zam.id);
                    IsBusy = false;
                });
            }
        }
        private void ZmenaUsekuNaAktualni()
        {
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamOblasti = new ObservableCollection<OblastVyroby>(seznamOblastiVse.Where(d => d.idUseku == Zam.idUseku).ToList());
                foreach (var item in SeznamOblasti)
                {
                    item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPracovist.Where(d => d.idOblasti == item.id).ToList());
                }
                IsBusy = false;
            });
        }
        private void ZmenaUseku(int idUseku)
        {
            Task.Run(() =>
            {
                IsBusy = true;
                SeznamOblasti = new ObservableCollection<OblastVyroby>(seznamOblastiVse.Where(d => d.idUseku == idUseku).ToList());
                foreach (var item in SeznamOblasti)
                {
                    item.seznamPracovist = new ObservableCollection<Pracoviste>(seznamPracovist.Where(d => d.idOblasti == item.id).ToList());
                }
                IsBusy = false;
            });
        }
    }
}

