﻿using eTraining.Commands;
using eTraining.Helpers;
using eTraining.Models;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace eTraining.ViewModels.ZamVM
{
    class ZadaniZamViewModel: ViewModelBase, IPageViewModel
    {
        public static event EventHandlerZpet Zpet = delegate { };
        public static event EventHandlerZpetSNovymZam ZpetSeZam = delegate { };

        private bool _update;
        private Zamestnanec _zam;
        private bool _chyba;
        private string _chybaPopis;
        private bool _isBusy;
        private DateTime _datumNastupu;
        private DateTime _terminZaskoleni;
        ObservableCollection<SmenovyModel> _smenoveModelyProVyber;
        ObservableCollection<Pozice> _poziceProVyber;

        public RelayCommand UlozitCommand { get; private set; }
        public RelayCommand ZavriZadaniCommand { get; private set; }
        public string Name
        {
            get
            {
                return "Zadani";
            }
        }
        public Zamestnanec Zam
        {
            get { return _zam; }
            set
            {
                if (_zam != value)
                {
                    _zam = value;
                    OnPropertyChanged("Zam");
                }
            }
        }
        public bool Chyba
        {
            get { return _chyba; }
            set
            {
                if (_chyba != value)
                {
                    _chyba = value;
                    OnPropertyChanged("Chyba");
                }
            }
        }
        public string ChybaPopis
        {
            get { return _chybaPopis; }
            set
            {
                if (_chybaPopis != value)
                {
                    _chybaPopis = value;
                    OnPropertyChanged("ChybaPopis");
                }
            }
        }
        public bool IsBusy
        {
            get { return _isBusy; }
            set
            {
                if (_isBusy != value)
                {
                    _isBusy = value;
                    OnPropertyChanged("IsBusy");
                }
            }
        }
        public bool Update
        {
            get { return _update; }
            set
            {
                if (_update != value)
                {
                    _update = value;
                    OnPropertyChanged("Update");
                }
            }
        }
        public ObservableCollection<SmenovyModel> SmenoveModelyProVyber
        {
            get { return _smenoveModelyProVyber; }
            set
            {
                if (_smenoveModelyProVyber != value)
                {
                    _smenoveModelyProVyber = value;
                    OnPropertyChanged("SmenoveModelyProVyber");
                }
            }
        }
        public ObservableCollection<Pozice> PoziceProVyber
        {
            get { return _poziceProVyber; }
            set
            {
                if (_poziceProVyber != value)
                {
                    _poziceProVyber = value;
                    OnPropertyChanged("PoziceProVyber");
                }
            }
        }
        public DateTime DatumNastupu
        {
            get { return _datumNastupu; }
            set
            {
                if (_datumNastupu != value)
                {
                    _datumNastupu = value;
                    TerminZaskoleni = DatumNastupu.AddDays(31);
                    OnPropertyChanged("DatumNastupu");
                }
            }
        }
        public DateTime TerminZaskoleni
        {
            get { return _terminZaskoleni; }
            set
            {
                if (_terminZaskoleni != value)
                {
                    _terminZaskoleni = value;
                    OnPropertyChanged("TerminZaskoleni");
                }
            }
        }
        public ZadaniZamViewModel()
        {
            Update = false;
            Zam = new Zamestnanec();
            DatumNastupu = DateTime.Now;
            Zam.aktivni = true;
            NactiDataProCB();
            UlozitCommand = new RelayCommand(param => this.Ulozit());
            ZavriZadaniCommand = new RelayCommand(param => this.ZavriZadani());
        }
        public ZadaniZamViewModel(Zamestnanec zamestnanec)
        {
            Update = true;
            Zam = zamestnanec;
            DatumNastupu = zamestnanec.datumNastupu;
            TerminZaskoleni = zamestnanec.terminZaskoleni.Value;
            NactiDataProCB();
            UlozitCommand = new RelayCommand(param => this.Ulozit());
            ZavriZadaniCommand = new RelayCommand(param => this.ZavriZadani());
        }
        private void NactiDataProCB()
        {
            Task.Run(() =>
            {
                IsBusy = true;
                SmenoveModelyProVyber = SmenovyModel.SelectSmenoveModelyProCB();
                PoziceProVyber = Pozice.SelectPoziceProCB();
                IsBusy = false;
            });
        }
        private void Ulozit()
        {
            Zam.terminZaskoleni = TerminZaskoleni;
            if (Update)
            {
                if (DatumNastupu.Date != Zam.datumNastupu.Date)
                {
                    Zam.poznamka = null;
                    Zam.datumNastupu = DatumNastupu;
                }
            }
            if (Kontrola())
            {
                if (Update)
                {
                    if (!Zamestnanec.EditaceZamestnanece(Zam))
                    {
                        Task.Run(() =>
                        {
                            Chyba = true;
                            ChybaPopis = "Nastala chyba při ukládání";
                            System.Threading.Thread.Sleep(2000);
                            Chyba = false;
                        });
                    }
                    else
                    {
                        ZavriZadani();
                    }
                }
                else
                {
                    Zam.datumNastupu = DatumNastupu;
                    Zam.id = Zamestnanec.VlozitZamestnance(Zam);
                    
                    if (Zam.id == 0)
                    {

                        Task.Run(() =>
                        {
                            Chyba = true;
                            ChybaPopis = "Nastala chyba při ukládání";
                            System.Threading.Thread.Sleep(2000);
                            Chyba = false;
                        });
                    }
                    else
                    {
                        IsBusy = true;
                        CheckListZam.VlozitPrvniDataProKartu(CheckListZam.SelectCheckListProNovehoZam(Zam.id));
                        Hodnoceni.VlozitPrvniHodnoceni(Zam.id);
                        IsBusy = false;
                        ZavriZadaniSeZam();   
                    }
                }
                Zam.terminZaskoleni = Zam.datumNastupu.AddDays(31);
                Zam.pocetDniZaskoleni = (DateTime.Now.Date - Zam.datumNastupu).Days;
                if (Zam.pocetDniZaskoleni < 0) Zam.pocetDniZaskoleni = 0;
                if (Zam.pocetDniZaskoleni < 15) Zam.verzeZaskoleni = 1;
                else if (Zam.pocetDniZaskoleni >= 15 && Zam.pocetDniZaskoleni < 32) Zam.verzeZaskoleni = 2;
                else Zam.verzeZaskoleni = 3;
            }
            else
            {
                Task.Run(() =>
                {
                    Chyba = true;
                    System.Threading.Thread.Sleep(3000);
                    Chyba = false;
                });
            }
        }
        private bool Kontrola()
        {
            if (String.IsNullOrEmpty(Zam.osCislo))
            {
                ChybaPopis = "Vyplňte os. číslo";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.jmeno))
            {
                ChybaPopis = "Vyplňte jméno";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.prijmeni))
            {
                ChybaPopis = "Vyplňte příjmení";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.stredisko))
            {
                ChybaPopis = "Vyplňte středisko";
                return false;
            }
            if (DatumNastupu < new DateTime(1900, 1, 1))
            {
                ChybaPopis = "Vyplňte platné datum nástupu";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.pohlavi))
            {
                ChybaPopis = "Vyberte pohlaví";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.smenovyModel))
            {
                ChybaPopis = "Vyberte směnový model";
                return false;
            }
            if (String.IsNullOrEmpty(Zam.pozice))
            {
                ChybaPopis = "Vyberte pozici";
                return false;
            }
            if (!Update && Zamestnanec.CheckZalozeni(Zam.osCislo, DatumNastupu))
            {
                ChybaPopis = "Tento uživatel je již založen";
                return false;
            }
            return true;
        }
        private void ZavriZadani()
        {
            Zpet();
        }
        private void ZavriZadaniSeZam()
        {
            ZpetSeZam(Zam);
        }
    }
}
